<?php

/**
 * Provides a form to create and edit time entries.
 */
function time_entry_form($form, &$form_state, $type = NULL, $time_entry = NULL) {
  if (is_null($time_entry)) {
    $values = array('type' => $time_entry);
    if(isset($form_state['values'])) {
      $values += $form_state['values'];
    }
    $time_entry = time_entry_create($values);
    
    
    $time_entry = time_entry_create(array('type' => $type));
  }
  
  if (is_null($type)) {
    $type = $time_entry->type;
  }

  $form_state['time_entry'] = $time_entry;

  $form['type'] = array(
    '#type' => 'value',
    '#default_value' => $type
  );

  $form['id'] = array(
    '#type' => 'value',
    '#default_value' => $time_entry->id ? $time_entry->id : 0
  );

  field_attach_form('time_entry', $time_entry, $form, $form_state);

  $start = $time_entry->time? format_date($time_entry->time, 'custom', 'c') : '';
  $form['start'] = array(
    '#type' => 'textfield',
    '#title' => t('Start'),
    '#description' => t('Format: %format', array('%format' => format_date(time(), 'custom', 'c'))),
    '#required' => TRUE,
    '#default_value' => $start,
  );

  $end = $time_entry->time && $time_entry->duration? format_date($time_entry->time + $time_entry->duration, 'custom', 'c') : '';
  $form['end'] = array(
    '#type' => 'textfield',
    '#title' => t('End'),
    '#description' => t('Format: %format', array('%format' => format_date(time(), 'custom', 'c'))),
    '#required' => TRUE,
    '#default_value' => $end
  );

  $form['actions'] = array(
    '#type' => 'actions'
  );

  $form['actions']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Create Time Entry'),
    '#weight' => 40,
  );

  return $form;
}

/**
 * Validate time entry creation form.
 */
function time_entry_form_validate($form, &$form_state) {
  $form_state['values']['time'] = strtotime($form_state['values']['start']);
  $form_state['values']['duration'] = strtotime($form_state['values']['end']) - $form_state['values']['time'];

  if ($form_state['values']['duration'] < 0) {
    form_set_error('start', t('Start date must be lower than end date.'));
  }

  if (empty($form_state['values']['start'])) {
    form_set_error($time_field, t('You have to specify a valid date.'));
  }
}

/**
 * Save submitted time entry.
 */
function time_entry_form_submit($form, &$form_state) {
  entity_form_submit_build_entity('time_entry', $form_state['time_entry'], $form, $form_state);
  entity_save('time_entry', $form_state['time_entry']);
}

/**
 * Confirm delete form.
 */
function time_entry_delete_confirm($form, &$form_state, $time_entry) {
  $form['id'] = array(
    '#type' => 'value',
    '#value' => $time_entry->id,
  );

  return confirm_form($form, t('Are you sure you want to delete this Time Entry?'), '<front>', t('This action cannot be undone.'), t('Delete'), t('Cancel'));
}

/**
 * Delete confirmed time entry.
 */
function time_entry_delete_confirm_submit($form, &$form_state) {
  if ($form_state['values']['confirm']) {
    $time_entry = time_entry_load($form_state['values']['id']);

    time_entry_delete($time_entry);

    drupal_set_message(t('Time Entry has been deleted.'));
  }

  $form_state['redirect'] = '<front>';
}
